Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Refs ¶
type Refs struct {
Data []byte
DataStr string
DataLen int
DataStrLen int
Candidates semver.SemverCandidateList
MasterRefHash string
IndexHeadLineEnd int
IndexHeadLineStart int
IndexMasterLineEnd int
IndexMasterLineStart int
}
Refs collects information about git references for one specific repository.
func FetchRefs ¶
FetchRefs downloads and processes refs data from Github and ultimately contructs a Refs instance with it.
func NewRefs ¶
NewRefs creates a new Refs instance from raw refs data fetched from Github (or elsewhere).
func (Refs) Reserialize ¶
Reserialize changes the refs data to incorporate the selected version as the HEAD instead of the default HEAD.
This code was written by Gustavo Niemeyer, Nathan Youngman and Geert-Johan Riemer.
type RequestContext ¶
RequestContext is a struct that keeps track of information that is relevant to one specific request.
func NewRequestContext ¶
func NewRequestContext(dbSession *gocql.Session) RequestContext
NewRequestContext creates a new RequestContext.
Click to show internal directories.
Click to hide internal directories.